(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     40260,        659]
NotebookOptionsPosition[     40563,        645]
NotebookOutlinePosition[     41120,        668]
CellTagsIndexPosition[     41077,        665]
WindowTitle->Currency Trade Alert
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Set Up a Currency Trade Alert", "Title"],

Cell[CellGroupData[{

Cell["\<\
Analyze exchange rate trends with advanced forecasting algorithms, and make \
trading decisions based on trade deadline, estimated future trend, and risk \
preference.\
\>", "Subsection"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`alg1$$ = False, $CellContext`alg2$$ = 
  False, $CellContext`alg3$$ = True, $CellContext`alg4$$ = 
  False, $CellContext`alg5$$ = False, $CellContext`deadline$$ = 
  0.2, $CellContext`mtrend$$ = 0.5, $CellContext`risk$$ = 
  0.5, $CellContext`lastdate$$ = 3623616000, $CellContext`lastval$$ = 
  79.128301143646}, 
  TagBox[GridBox[{
     {
      PanelBox[
       TagBox[GridBox[{
          {
           StyleBox["\<\"Your Parameters\"\>",
            StripOnInput->False,
            FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
          {"\<\"Estimated next trade deadline\"\>", 
           SliderBox[Dynamic[$CellContext`deadline$$],
            ImageSize->Small], "\[SpanFromLeft]"},
          {"\<\"Estimated future trend\"\>", 
           SliderBox[Dynamic[$CellContext`mtrend$$],
            ImageSize->Small], "\[SpanFromLeft]"},
          {"\<\"Risk preference\"\>", 
           SliderBox[Dynamic[$CellContext`risk$$],
            ImageSize->Small], "\[SpanFromLeft]"},
          {"\<\"\"\>", "\<\"\"\>", ""},
          {
           StyleBox["\<\"Forecast Algorithm\"\>",
            StripOnInput->False,
            FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
          {"\<\"Inertia\"\>", 
           CheckboxBox[Dynamic[$CellContext`alg1$$]], 
           DynamicBox[ToBoxes[
             If[$CellContext`alg1$$, 
              
              If[$CellContext`risk$$ - $CellContext`mtrend$$ + \
$CellContext`deadline$$ < 0.4, "Trade", "Wait"], ""], StandardForm],
            ImageSizeCache->{0., {0., 6.}}]},
          {"\<\"Futures market\"\>", 
           CheckboxBox[Dynamic[$CellContext`alg2$$]], 
           DynamicBox[ToBoxes[
             If[$CellContext`alg2$$, 
              
              If[$CellContext`risk$$ - $CellContext`mtrend$$ + \
$CellContext`deadline$$ < 0, "Trade", "Wait"], ""], StandardForm],
            ImageSizeCache->{0., {0., 6.}}]},
          {"\<\"Klinger Oscillator\"\>", 
           CheckboxBox[Dynamic[$CellContext`alg3$$]], 
           DynamicBox[ToBoxes[
             If[$CellContext`alg3$$, 
              
              If[$CellContext`risk$$ - $CellContext`mtrend$$ + \
$CellContext`deadline$$ < 0.2, "Trade", "Wait", ""]], StandardForm],
            ImageSizeCache->{21., {0., 8.}}]},
          {"\<\"Random walk index\"\>", 
           CheckboxBox[Dynamic[$CellContext`alg4$$]], 
           DynamicBox[ToBoxes[
             If[$CellContext`alg4$$, 
              
              If[$CellContext`risk$$ - $CellContext`mtrend$$ + \
$CellContext`deadline$$ < 0.8, "Trade", "Wait"], ""], StandardForm],
            ImageSizeCache->{0., {0., 6.}}]},
          {"\<\"Linear regression trendlines\"\>", 
           CheckboxBox[Dynamic[$CellContext`alg5$$]], 
           DynamicBox[ToBoxes[
             If[$CellContext`alg5$$, 
              
              If[$CellContext`risk$$ - $CellContext`mtrend$$ + \
$CellContext`deadline$$ < 2, "Trade", "Wait"], ""], StandardForm],
            ImageSizeCache->{0., {0., 6.}}]}
         },
         AutoDelete->False,
         GridBoxAlignment->{"Columns" -> {{Left}}},
         GridBoxDividers->{
          "Rows" -> {False, False, False, False, False, False, True, {False}}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], 
      DynamicBox[ToBoxes[
        Show[
         DateListPlot[{{{2013, 10, 31}, 72.86739945411699}, {{2013, 11, 1}, 
            73.6388027668}, {{2013, 11, 2}, 74.140000343323}, {{2013, 11, 3}, 
            74.140000343323}, {{2013, 11, 4}, 74.11440014839201}, {{2013, 11, 
            5}, 73.989099264145}, {{2013, 11, 6}, 74.228000640869}, {{2013, 
            11, 7}, 73.97519946098299}, {{2013, 11, 8}, 74.57730174064599}, {{
            2013, 11, 9}, 74.809998273849}, {{2013, 11, 10}, 
            74.809998273849}, {{2013, 11, 11}, 74.92520213127099}, {{2013, 11,
             12}, 74.585098028183}, {{2013, 11, 13}, 74.416697025299}, {{2013,
             11, 14}, 74.162000417709}, {{2013, 11, 15}, 74.371600151062}, {{
            2013, 11, 16}, 74.093997478485}, {{2013, 11, 17}, 
            74.093997478485}, {{2013, 11, 18}, 74.171298742294}, {{2013, 11, 
            19}, 74.058198928833}, {{2013, 11, 20}, 73.724001646042}, {{2013, 
            11, 21}, 74.449598789215}, {{2013, 11, 22}, 74.232697486877}, {{
            2013, 11, 23}, 73.764002323151}, {{2013, 11, 24}, 
            73.764002323151}, {{2013, 11, 25}, 73.79530072212201}, {{2013, 11,
             26}, 73.890697956085}, {{2013, 11, 27}, 73.707699775696}, {{2013,
             11, 28}, 73.67569804191601}, {{2013, 11, 29}, 
            73.513501882553}, {{2013, 11, 30}, 73.56950044632}, {{2013, 12, 
            1}, 73.56950044632}, {{2013, 12, 2}, 73.60519766807599}, {{2013, 
            12, 3}, 73.84459972381599}, {{2013, 12, 4}, 73.575401306152}, {{
            2013, 12, 5}, 73.608702421188}, {{2013, 12, 6}, 
            73.159301280975}, {{2013, 12, 7}, 72.962999343872}, {{2013, 12, 
            8}, 72.962999343872}, {{2013, 12, 9}, 72.956502437592}, {{2013, 
            12, 10}, 72.787600755692}, {{2013, 12, 11}, 72.651499509811}, {{
            2013, 12, 12}, 72.537398338318}, {{2013, 12, 13}, 
            72.727799415588}, {{2013, 12, 14}, 72.769999504089}, {{2013, 12, 
            15}, 72.769999504089}, {{2013, 12, 16}, 72.78950214385999}, {{
            2013, 12, 17}, 72.671502828598}, {{2013, 12, 18}, 
            72.62510061264}, {{2013, 12, 19}, 73.094302415848}, {{2013, 12, 
            20}, 73.225200176239}, {{2013, 12, 21}, 73.1369972229}, {{2013, 
            12, 22}, 73.1369972229}, {{2013, 12, 23}, 73.112201690674}, {{
            2013, 12, 24}, 73.006802797318}, {{2013, 12, 25}, 
            73.12610149383501}, {{2013, 12, 26}, 73.166298866272}, {{2013, 12,
             27}, 73.01669716834999}, {{2013, 12, 28}, 72.754001617432}, {{
            2013, 12, 29}, 72.754001617432}, {{2013, 12, 30}, 
            72.721999883652}, {{2013, 12, 31}, 72.422802448273}, {{2014, 1, 
            1}, 72.764497995377}, {{2014, 1, 2}, 72.647202014923}, {{2014, 1, 
            3}, 73.178297281265}, {{2014, 1, 4}, 73.588699102402}, {{2014, 1, 
            5}, 73.588699102402}, {{2014, 1, 6}, 73.557299375534}, {{2014, 1, 
            7}, 73.368400335312}, {{2014, 1, 8}, 73.43760132789599}, {{2014, 
            1, 9}, 73.681098222733}, {{2014, 1, 10}, 73.49100112915}, {{2014, 
            1, 11}, 73.161500692368}, {{2014, 1, 12}, 73.161500692368}, {{
            2014, 1, 13}, 73.141700029373}, {{2014, 1, 14}, 
            73.159301280975}, {{2014, 1, 15}, 73.162001371384}, {{2014, 1, 
            16}, 73.528897762299}, {{2014, 1, 17}, 73.44840168952899}, {{2014,
             1, 18}, 73.853498697281}, {{2014, 1, 19}, 73.853498697281}, {{
            2014, 1, 20}, 73.92539978027301}, {{2014, 1, 21}, 
            73.822999000549}, {{2014, 1, 22}, 73.762601613998}, {{2014, 1, 
            23}, 73.827999830246}, {{2014, 1, 24}, 73.055100440979}, {{2014, 
            1, 25}, 73.11350107193}, {{2014, 1, 26}, 73.11350107193}, {{2014, 
            1, 27}, 73.062801361084}, {{2014, 1, 28}, 73.130398988724}, {{
            2014, 1, 29}, 73.237001895905}, {{2014, 1, 30}, 
            73.21900129318199}, {{2014, 1, 31}, 73.75450134277301}, {{2014, 2,
             1}, 74.14100170135501}, {{2014, 2, 2}, 74.14100170135501}, {{
            2014, 2, 3}, 74.143797159195}, {{2014, 2, 4}, 
            73.95300269126899}, {{2014, 2, 5}, 73.986899852753}, {{2014, 2, 
            6}, 73.888301849365}, {{2014, 2, 7}, 73.57320189476}, {{2014, 2, 
            8}, 73.338800668716}, {{2014, 2, 9}, 73.338800668716}, {{2014, 2, 
            10}, 73.42680096626299}, {{2014, 2, 11}, 73.283702135086}, {{2014,
             2, 12}, 73.331499099731}, {{2014, 2, 13}, 73.594301939011}, {{
            2014, 2, 14}, 73.120301961899}, {{2014, 2, 15}, 
            73.030000925064}, {{2014, 2, 16}, 73.030000925064}, {{2014, 2, 
            17}, 72.971397638321}, {{2014, 2, 18}, 72.971701622009}, {{2014, 
            2, 19}, 72.67199754715}, {{2014, 2, 20}, 72.836399078369}, {{2014,
             2, 21}, 72.88100123405499}, {{2014, 2, 22}, 72.794502973557}, {{
            2014, 2, 23}, 72.794502973557}, {{2014, 2, 24}, 
            72.793698310852}, {{2014, 2, 25}, 72.808599472046}, {{2014, 2, 
            26}, 72.748702764511}, {{2014, 2, 27}, 73.093497753143}, {{2014, 
            2, 28}, 72.95089960098299}, {{2014, 3, 1}, 72.458499670029}, {{
            2014, 3, 2}, 72.458499670029}, {{2014, 3, 3}, 72.595298290253}, {{
            2014, 3, 4}, 72.802698612213}, {{2014, 3, 5}, 72.770702838898}, {{
            2014, 3, 6}, 72.82549738884}, {{2014, 3, 7}, 72.133898735046}, {{
            2014, 3, 8}, 72.061502933502}, {{2014, 3, 9}, 72.061502933502}, {{
            2014, 3, 10}, 72.06429839134199}, {{2014, 3, 11}, 
            72.061198949814}, {{2014, 3, 12}, 72.176599502563}, {{2014, 3, 
            13}, 71.921700239182}, {{2014, 3, 14}, 72.11030125618}, {{2014, 3,
             15}, 71.895498037338}, {{2014, 3, 16}, 71.895498037338}, {{2014, 
            3, 17}, 71.906799077988}, {{2014, 3, 18}, 71.810501813889}, {{
            2014, 3, 19}, 71.786201000214}, {{2014, 3, 20}, 
            72.343701124191}, {{2014, 3, 21}, 72.574198246002}, {{2014, 3, 
            22}, 72.496098279953}, {{2014, 3, 23}, 72.496098279953}, {{2014, 
            3, 24}, 72.503197193146}, {{2014, 3, 25}, 72.263699769974}, {{
            2014, 3, 26}, 72.332698106766}, {{2014, 3, 27}, 
            72.557902336121}, {{2014, 3, 28}, 72.75959849357601}, {{2014, 3, 
            29}, 72.73790240287799}, {{2014, 3, 30}, 72.73790240287799}, {{
            2014, 3, 31}, 72.72440195083601}, {{2014, 4, 1}, 
            72.600501775742}, {{2014, 4, 2}, 72.498697042465}, {{2014, 4, 3}, 
            72.646200656891}, {{2014, 4, 4}, 72.905999422073}, {{2014, 4, 5}, 
            72.968697547913}, {{2014, 4, 6}, 72.968697547913}, {{2014, 4, 7}, 
            72.992700338364}, {{2014, 4, 8}, 72.759300470352}, {{2014, 4, 9}, 
            72.49900102615399}, {{2014, 4, 10}, 72.182601690292}, {{2014, 4, 
            11}, 72.021198272705}, {{2014, 4, 12}, 72.023499011993}, {{2014, 
            4, 13}, 72.023499011993}, {{2014, 4, 14}, 72.234499454498}, {{
            2014, 4, 15}, 72.378301620483}, {{2014, 4, 16}, 
            72.391402721405}, {{2014, 4, 17}, 72.372001409531}, {{2014, 4, 
            18}, 72.393500804901}, {{2014, 4, 19}, 72.385001182556}, {{2014, 
            4, 20}, 72.385001182556}, {{2014, 4, 21}, 72.387397289276}, {{
            2014, 4, 22}, 72.509497404099}, {{2014, 4, 23}, 
            72.426497936249}, {{2014, 4, 24}, 72.36390113830599}, {{2014, 4, 
            25}, 72.295898199081}, {{2014, 4, 26}, 72.288298606873}, {{2014, 
            4, 27}, 72.288298606873}, {{2014, 4, 28}, 72.25279808044401}, {{
            2014, 4, 29}, 72.188997268677}, {{2014, 4, 30}, 
            72.406297922134}, {{2014, 5, 1}, 72.100901603699}, {{2014, 5, 2}, 
            72.100698947906}, {{2014, 5, 3}, 72.073501348495}, {{2014, 5, 4}, 
            72.073501348495}, {{2014, 5, 5}, 72.07099795341499}, {{2014, 5, 
            6}, 72.068697214127}, {{2014, 5, 7}, 71.812301874161}, {{2014, 5, 
            8}, 71.883499622345}, {{2014, 5, 9}, 72.259002923965}, {{2014, 5, 
            10}, 72.666001319885}, {{2014, 5, 11}, 72.666001319885}, {{2014, 
            5, 12}, 72.67339825630201}, {{2014, 5, 13}, 72.695499658585}, {{
            2014, 5, 14}, 72.970300912857}, {{2014, 5, 15}, 
            72.908902168274}, {{2014, 5, 16}, 72.91579842567401}, {{2014, 5, 
            17}, 73.027002811432}, {{2014, 5, 18}, 73.027002811432}, {{2014, 
            5, 19}, 73.012697696686}, {{2014, 5, 20}, 72.94499874115}, {{2014,
             5, 21}, 72.997802495956}, {{2014, 5, 22}, 73.06150197982801}, {{
            2014, 5, 23}, 73.229199647903}, {{2014, 5, 24}, 
            73.36750030517601}, {{2014, 5, 25}, 73.36750030517601}, {{2014, 5,
             26}, 73.38160276413001}, {{2014, 5, 27}, 73.28929901123}, {{2014,
             5, 28}, 73.335301876068}, {{2014, 5, 29}, 73.556500673294}, {{
            2014, 5, 30}, 73.523998260498}, {{2014, 5, 31}, 
            73.357498645782}, {{2014, 6, 1}, 73.357498645782}, {{2014, 6, 2}, 
            73.399299383163}, {{2014, 6, 3}, 73.53590130806}, {{2014, 6, 4}, 
            73.382598161697}, {{2014, 6, 5}, 73.52910041809099}, {{2014, 6, 
            6}, 73.205900192261}, {{2014, 6, 7}, 73.30049872398399}, {{2014, 
            6, 8}, 73.30049872398399}, {{2014, 6, 9}, 73.291200399399}, {{
            2014, 6, 10}, 73.56889843940701}, {{2014, 6, 11}, 
            73.83120059967}, {{2014, 6, 12}, 73.891001939774}, {{2014, 6, 13},
             73.795002698898}, {{2014, 6, 14}, 73.85519742965701}, {{2014, 6, 
            15}, 73.85519742965701}, {{2014, 6, 16}, 73.901897668839}, {{2014,
             6, 17}, 73.672997951508}, {{2014, 6, 18}, 73.81790280342099}, {{
            2014, 6, 19}, 73.599201440811}, {{2014, 6, 20}, 
            73.483502864838}, {{2014, 6, 21}, 73.523998260498}, {{2014, 6, 
            22}, 73.523998260498}, {{2014, 6, 23}, 73.55939745903}, {{2014, 6,
             24}, 73.517000675201}, {{2014, 6, 25}, 73.504602909088}, {{2014, 
            6, 26}, 73.358702659607}, {{2014, 6, 27}, 73.454600572586}, {{
            2014, 6, 28}, 73.260098695755}, {{2014, 6, 29}, 
            73.260098695755}, {{2014, 6, 30}, 73.282599449158}, {{2014, 7, 1},
             73.03829789161699}, {{2014, 7, 2}, 73.099398612976}, {{2014, 7, 
            3}, 73.223298788071}, {{2014, 7, 4}, 73.475098609924}, {{2014, 7, 
            5}, 73.556500673294}, {{2014, 7, 6}, 73.556500673294}, {{2014, 7, 
            7}, 73.59380125999499}, {{2014, 7, 8}, 73.492699861526}, {{2014, 
            7, 9}, 73.460799455643}, {{2014, 7, 10}, 73.313498497009}, {{2014,
             7, 11}, 73.48889708518999}, {{2014, 7, 12}, 73.489499092102}, {{
            2014, 7, 13}, 73.489499092102}, {{2014, 7, 14}, 
            73.50509762764}, {{2014, 7, 15}, 73.418700695038}, {{2014, 7, 16},
             73.70169758796699}, {{2014, 7, 17}, 73.926198482513}, {{2014, 7, 
            18}, 73.953598737717}, {{2014, 7, 19}, 73.93400073051501}, {{2014,
             7, 20}, 73.93400073051501}, {{2014, 7, 21}, 
            73.90159964561501}, {{2014, 7, 22}, 73.947298526764}, {{2014, 7, 
            23}, 74.258100986481}, {{2014, 7, 24}, 74.299198389053}, {{2014, 
            7, 25}, 74.276500940323}, {{2014, 7, 26}, 74.45999979972801}, {{
            2014, 7, 27}, 74.45999979972801}, {{2014, 7, 28}, 
            74.453800916672}, {{2014, 7, 29}, 74.411702156067}, {{2014, 7, 
            30}, 74.576497077942}, {{2014, 7, 31}, 74.656099081039}, {{2014, 
            8, 1}, 74.693500995636}, {{2014, 8, 2}, 74.4520008564}, {{2014, 8,
             3}, 74.4520008564}, {{2014, 8, 4}, 74.48850274086}, {{2014, 8, 
            5}, 74.505400657654}, {{2014, 8, 6}, 74.79540109634401}, {{2014, 
            8, 7}, 74.721401929855}, {{2014, 8, 8}, 74.848902225494}, {{2014, 
            8, 9}, 74.561500549316}, {{2014, 8, 10}, 74.561500549316}, {{2014,
             8, 11}, 74.594300985336}, {{2014, 8, 12}, 74.711102247238}, {{
            2014, 8, 13}, 74.803501367569}, {{2014, 8, 14}, 
            74.821698665619}, {{2014, 8, 15}, 74.828499555588}, {{2014, 8, 
            16}, 74.637997150421}, {{2014, 8, 17}, 74.637997150421}, {{2014, 
            8, 18}, 74.684798717499}, {{2014, 8, 19}, 74.84920024871799}, {{
            2014, 8, 20}, 75.073897838593}, {{2014, 8, 21}, 
            75.414800643921}, {{2014, 8, 22}, 75.29810070991499}, {{2014, 8, 
            23}, 75.51149725914}, {{2014, 8, 24}, 75.51149725914}, {{2014, 8, 
            25}, 75.808399915695}, {{2014, 8, 26}, 75.829100608826}, {{2014, 
            8, 27}, 75.940501689911}, {{2014, 8, 28}, 75.79950094223}, {{2014,
             8, 29}, 75.86100101470899}, {{2014, 8, 30}, 76.139497756958}, {{
            2014, 8, 31}, 76.139497756958}, {{2014, 9, 1}, 
            76.133900880814}, {{2014, 9, 2}, 76.16320252418501}, {{2014, 9, 
            3}, 76.13540291786201}, {{2014, 9, 4}, 76.03639960289}, {{2014, 9,
             5}, 77.302199602127}, {{2014, 9, 6}, 77.20819711685199}, {{2014, 
            9, 7}, 77.20819711685199}, {{2014, 9, 8}, 77.19150185584999}, {{
            2014, 9, 9}, 77.535897493362}, {{2014, 9, 10}, 77.30929851532}, {{
            2014, 9, 11}, 77.382302284241}, {{2014, 9, 12}, 
            77.384102344513}, {{2014, 9, 13}, 77.1399974823}, {{2014, 9, 14}, 
            77.1399974823}, {{2014, 9, 15}, 77.145600318909}, {{2014, 9, 16}, 
            77.28989720344501}, {{2014, 9, 17}, 77.218902111053}, {{2014, 9, 
            18}, 77.893102169037}, {{2014, 9, 19}, 77.415901422501}, {{2014, 
            9, 20}, 77.948397397995}, {{2014, 9, 21}, 77.948397397995}, {{
            2014, 9, 22}, 77.907001972198}, {{2014, 9, 23}, 
            77.828001976013}, {{2014, 9, 24}, 77.84219980239901}, {{2014, 9, 
            25}, 78.26550006866499}, {{2014, 9, 26}, 78.387701511383}, {{2014,
             9, 27}, 78.84200215339699}, {{2014, 9, 28}, 
            78.84200215339699}, {{2014, 9, 29}, 78.914499282837}, {{2014, 9, 
            30}, 78.798800706863}, {{2014, 10, 1}, 79.17839884758}, {{2014, 
            10, 2}, 79.220497608185}, {{2014, 10, 3}, 78.924697637558}, {{
            2014, 10, 4}, 79.910498857498}, {{2014, 10, 5}, 
            79.910498857498}, {{2014, 10, 6}, 79.936397075653}, {{2014, 10, 
            7}, 79.029202461243}, {{2014, 10, 8}, 78.92689704895}, {{2014, 10,
             9}, 78.556400537491}, {{2014, 10, 10}, 78.836101293564}, {{2014, 
            10, 11}, 79.183000326157}, {{2014, 10, 12}, 79.183000326157}, {{
            2014, 10, 13}, 79.07509803772001}, {{2014, 10, 14}, 
            78.522801399231}, {{2014, 10, 15}, 79.082602262497}, {{2014, 10, 
            16}, 77.97269821167}, {{2014, 10, 17}, 78.07739973068199}, {{2014,
             10, 18}, 78.37849855423}, {{2014, 10, 19}, 78.37849855423}, {{
            2014, 10, 20}, 78.471398353577}, {{2014, 10, 21}, 
            78.162598609924}, {{2014, 10, 22}, 78.670799732208}, {{2014, 10, 
            23}, 79.068899154663}, {{2014, 10, 24}, 79.04509902000399}, {{
            2014, 10, 25}, 78.92040014267}, {{2014, 10, 26}, 
            78.92040014267}, {{2014, 10, 27}, 78.88860106468199}, {{2014, 10, 
            28}, 78.764700889587}, {{2014, 10, 29}, 78.518497943878}, {{2014, 
            10, 30}, 79.128301143646}}, Joined -> True, PlotRange -> {{
             AbsoluteTime[
              
              Part[{{{2013, 10, 31}, 72.86739945411699}, {{2013, 11, 1}, 
                 73.6388027668}, {{2013, 11, 2}, 74.140000343323}, {{2013, 11,
                  3}, 74.140000343323}, {{2013, 11, 4}, 74.11440014839201}, {{
                 2013, 11, 5}, 73.989099264145}, {{2013, 11, 6}, 
                 74.228000640869}, {{2013, 11, 7}, 73.97519946098299}, {{2013,
                  11, 8}, 74.57730174064599}, {{2013, 11, 9}, 
                 74.809998273849}, {{2013, 11, 10}, 74.809998273849}, {{2013, 
                 11, 11}, 74.92520213127099}, {{2013, 11, 12}, 
                 74.585098028183}, {{2013, 11, 13}, 74.416697025299}, {{2013, 
                 11, 14}, 74.162000417709}, {{2013, 11, 15}, 
                 74.371600151062}, {{2013, 11, 16}, 74.093997478485}, {{2013, 
                 11, 17}, 74.093997478485}, {{2013, 11, 18}, 
                 74.171298742294}, {{2013, 11, 19}, 74.058198928833}, {{2013, 
                 11, 20}, 73.724001646042}, {{2013, 11, 21}, 
                 74.449598789215}, {{2013, 11, 22}, 74.232697486877}, {{2013, 
                 11, 23}, 73.764002323151}, {{2013, 11, 24}, 
                 73.764002323151}, {{2013, 11, 25}, 73.79530072212201}, {{
                 2013, 11, 26}, 73.890697956085}, {{2013, 11, 27}, 
                 73.707699775696}, {{2013, 11, 28}, 73.67569804191601}, {{
                 2013, 11, 29}, 73.513501882553}, {{2013, 11, 30}, 
                 73.56950044632}, {{2013, 12, 1}, 73.56950044632}, {{2013, 12,
                  2}, 73.60519766807599}, {{2013, 12, 3}, 
                 73.84459972381599}, {{2013, 12, 4}, 73.575401306152}, {{2013,
                  12, 5}, 73.608702421188}, {{2013, 12, 6}, 
                 73.159301280975}, {{2013, 12, 7}, 72.962999343872}, {{2013, 
                 12, 8}, 72.962999343872}, {{2013, 12, 9}, 
                 72.956502437592}, {{2013, 12, 10}, 72.787600755692}, {{2013, 
                 12, 11}, 72.651499509811}, {{2013, 12, 12}, 
                 72.537398338318}, {{2013, 12, 13}, 72.727799415588}, {{2013, 
                 12, 14}, 72.769999504089}, {{2013, 12, 15}, 
                 72.769999504089}, {{2013, 12, 16}, 72.78950214385999}, {{
                 2013, 12, 17}, 72.671502828598}, {{2013, 12, 18}, 
                 72.62510061264}, {{2013, 12, 19}, 73.094302415848}, {{2013, 
                 12, 20}, 73.225200176239}, {{2013, 12, 21}, 
                 73.1369972229}, {{2013, 12, 22}, 73.1369972229}, {{2013, 12, 
                 23}, 73.112201690674}, {{2013, 12, 24}, 73.006802797318}, {{
                 2013, 12, 25}, 73.12610149383501}, {{2013, 12, 26}, 
                 73.166298866272}, {{2013, 12, 27}, 73.01669716834999}, {{
                 2013, 12, 28}, 72.754001617432}, {{2013, 12, 29}, 
                 72.754001617432}, {{2013, 12, 30}, 72.721999883652}, {{2013, 
                 12, 31}, 72.422802448273}, {{2014, 1, 1}, 
                 72.764497995377}, {{2014, 1, 2}, 72.647202014923}, {{2014, 1,
                  3}, 73.178297281265}, {{2014, 1, 4}, 73.588699102402}, {{
                 2014, 1, 5}, 73.588699102402}, {{2014, 1, 6}, 
                 73.557299375534}, {{2014, 1, 7}, 73.368400335312}, {{2014, 1,
                  8}, 73.43760132789599}, {{2014, 1, 9}, 73.681098222733}, {{
                 2014, 1, 10}, 73.49100112915}, {{2014, 1, 11}, 
                 73.161500692368}, {{2014, 1, 12}, 73.161500692368}, {{2014, 
                 1, 13}, 73.141700029373}, {{2014, 1, 14}, 
                 73.159301280975}, {{2014, 1, 15}, 73.162001371384}, {{2014, 
                 1, 16}, 73.528897762299}, {{2014, 1, 17}, 
                 73.44840168952899}, {{2014, 1, 18}, 73.853498697281}, {{2014,
                  1, 19}, 73.853498697281}, {{2014, 1, 20}, 
                 73.92539978027301}, {{2014, 1, 21}, 73.822999000549}, {{2014,
                  1, 22}, 73.762601613998}, {{2014, 1, 23}, 
                 73.827999830246}, {{2014, 1, 24}, 73.055100440979}, {{2014, 
                 1, 25}, 73.11350107193}, {{2014, 1, 26}, 73.11350107193}, {{
                 2014, 1, 27}, 73.062801361084}, {{2014, 1, 28}, 
                 73.130398988724}, {{2014, 1, 29}, 73.237001895905}, {{2014, 
                 1, 30}, 73.21900129318199}, {{2014, 1, 31}, 
                 73.75450134277301}, {{2014, 2, 1}, 74.14100170135501}, {{
                 2014, 2, 2}, 74.14100170135501}, {{2014, 2, 3}, 
                 74.143797159195}, {{2014, 2, 4}, 73.95300269126899}, {{2014, 
                 2, 5}, 73.986899852753}, {{2014, 2, 6}, 73.888301849365}, {{
                 2014, 2, 7}, 73.57320189476}, {{2014, 2, 8}, 
                 73.338800668716}, {{2014, 2, 9}, 73.338800668716}, {{2014, 2,
                  10}, 73.42680096626299}, {{2014, 2, 11}, 
                 73.283702135086}, {{2014, 2, 12}, 73.331499099731}, {{2014, 
                 2, 13}, 73.594301939011}, {{2014, 2, 14}, 
                 73.120301961899}, {{2014, 2, 15}, 73.030000925064}, {{2014, 
                 2, 16}, 73.030000925064}, {{2014, 2, 17}, 
                 72.971397638321}, {{2014, 2, 18}, 72.971701622009}, {{2014, 
                 2, 19}, 72.67199754715}, {{2014, 2, 20}, 72.836399078369}, {{
                 2014, 2, 21}, 72.88100123405499}, {{2014, 2, 22}, 
                 72.794502973557}, {{2014, 2, 23}, 72.794502973557}, {{2014, 
                 2, 24}, 72.793698310852}, {{2014, 2, 25}, 
                 72.808599472046}, {{2014, 2, 26}, 72.748702764511}, {{2014, 
                 2, 27}, 73.093497753143}, {{2014, 2, 28}, 
                 72.95089960098299}, {{2014, 3, 1}, 72.458499670029}, {{2014, 
                 3, 2}, 72.458499670029}, {{2014, 3, 3}, 72.595298290253}, {{
                 2014, 3, 4}, 72.802698612213}, {{2014, 3, 5}, 
                 72.770702838898}, {{2014, 3, 6}, 72.82549738884}, {{2014, 3, 
                 7}, 72.133898735046}, {{2014, 3, 8}, 72.061502933502}, {{
                 2014, 3, 9}, 72.061502933502}, {{2014, 3, 10}, 
                 72.06429839134199}, {{2014, 3, 11}, 72.061198949814}, {{2014,
                  3, 12}, 72.176599502563}, {{2014, 3, 13}, 
                 71.921700239182}, {{2014, 3, 14}, 72.11030125618}, {{2014, 3,
                  15}, 71.895498037338}, {{2014, 3, 16}, 71.895498037338}, {{
                 2014, 3, 17}, 71.906799077988}, {{2014, 3, 18}, 
                 71.810501813889}, {{2014, 3, 19}, 71.786201000214}, {{2014, 
                 3, 20}, 72.343701124191}, {{2014, 3, 21}, 
                 72.574198246002}, {{2014, 3, 22}, 72.496098279953}, {{2014, 
                 3, 23}, 72.496098279953}, {{2014, 3, 24}, 
                 72.503197193146}, {{2014, 3, 25}, 72.263699769974}, {{2014, 
                 3, 26}, 72.332698106766}, {{2014, 3, 27}, 
                 72.557902336121}, {{2014, 3, 28}, 72.75959849357601}, {{2014,
                  3, 29}, 72.73790240287799}, {{2014, 3, 30}, 
                 72.73790240287799}, {{2014, 3, 31}, 72.72440195083601}, {{
                 2014, 4, 1}, 72.600501775742}, {{2014, 4, 2}, 
                 72.498697042465}, {{2014, 4, 3}, 72.646200656891}, {{2014, 4,
                  4}, 72.905999422073}, {{2014, 4, 5}, 72.968697547913}, {{
                 2014, 4, 6}, 72.968697547913}, {{2014, 4, 7}, 
                 72.992700338364}, {{2014, 4, 8}, 72.759300470352}, {{2014, 4,
                  9}, 72.49900102615399}, {{2014, 4, 10}, 72.182601690292}, {{
                 2014, 4, 11}, 72.021198272705}, {{2014, 4, 12}, 
                 72.023499011993}, {{2014, 4, 13}, 72.023499011993}, {{2014, 
                 4, 14}, 72.234499454498}, {{2014, 4, 15}, 
                 72.378301620483}, {{2014, 4, 16}, 72.391402721405}, {{2014, 
                 4, 17}, 72.372001409531}, {{2014, 4, 18}, 
                 72.393500804901}, {{2014, 4, 19}, 72.385001182556}, {{2014, 
                 4, 20}, 72.385001182556}, {{2014, 4, 21}, 
                 72.387397289276}, {{2014, 4, 22}, 72.509497404099}, {{2014, 
                 4, 23}, 72.426497936249}, {{2014, 4, 24}, 
                 72.36390113830599}, {{2014, 4, 25}, 72.295898199081}, {{2014,
                  4, 26}, 72.288298606873}, {{2014, 4, 27}, 
                 72.288298606873}, {{2014, 4, 28}, 72.25279808044401}, {{2014,
                  4, 29}, 72.188997268677}, {{2014, 4, 30}, 
                 72.406297922134}, {{2014, 5, 1}, 72.100901603699}, {{2014, 5,
                  2}, 72.100698947906}, {{2014, 5, 3}, 72.073501348495}, {{
                 2014, 5, 4}, 72.073501348495}, {{2014, 5, 5}, 
                 72.07099795341499}, {{2014, 5, 6}, 72.068697214127}, {{2014, 
                 5, 7}, 71.812301874161}, {{2014, 5, 8}, 71.883499622345}, {{
                 2014, 5, 9}, 72.259002923965}, {{2014, 5, 10}, 
                 72.666001319885}, {{2014, 5, 11}, 72.666001319885}, {{2014, 
                 5, 12}, 72.67339825630201}, {{2014, 5, 13}, 
                 72.695499658585}, {{2014, 5, 14}, 72.970300912857}, {{2014, 
                 5, 15}, 72.908902168274}, {{2014, 5, 16}, 
                 72.91579842567401}, {{2014, 5, 17}, 73.027002811432}, {{2014,
                  5, 18}, 73.027002811432}, {{2014, 5, 19}, 
                 73.012697696686}, {{2014, 5, 20}, 72.94499874115}, {{2014, 5,
                  21}, 72.997802495956}, {{2014, 5, 22}, 
                 73.06150197982801}, {{2014, 5, 23}, 73.229199647903}, {{2014,
                  5, 24}, 73.36750030517601}, {{2014, 5, 25}, 
                 73.36750030517601}, {{2014, 5, 26}, 73.38160276413001}, {{
                 2014, 5, 27}, 73.28929901123}, {{2014, 5, 28}, 
                 73.335301876068}, {{2014, 5, 29}, 73.556500673294}, {{2014, 
                 5, 30}, 73.523998260498}, {{2014, 5, 31}, 
                 73.357498645782}, {{2014, 6, 1}, 73.357498645782}, {{2014, 6,
                  2}, 73.399299383163}, {{2014, 6, 3}, 73.53590130806}, {{
                 2014, 6, 4}, 73.382598161697}, {{2014, 6, 5}, 
                 73.52910041809099}, {{2014, 6, 6}, 73.205900192261}, {{2014, 
                 6, 7}, 73.30049872398399}, {{2014, 6, 8}, 
                 73.30049872398399}, {{2014, 6, 9}, 73.291200399399}, {{2014, 
                 6, 10}, 73.56889843940701}, {{2014, 6, 11}, 
                 73.83120059967}, {{2014, 6, 12}, 73.891001939774}, {{2014, 6,
                  13}, 73.795002698898}, {{2014, 6, 14}, 
                 73.85519742965701}, {{2014, 6, 15}, 73.85519742965701}, {{
                 2014, 6, 16}, 73.901897668839}, {{2014, 6, 17}, 
                 73.672997951508}, {{2014, 6, 18}, 73.81790280342099}, {{2014,
                  6, 19}, 73.599201440811}, {{2014, 6, 20}, 
                 73.483502864838}, {{2014, 6, 21}, 73.523998260498}, {{2014, 
                 6, 22}, 73.523998260498}, {{2014, 6, 23}, 73.55939745903}, {{
                 2014, 6, 24}, 73.517000675201}, {{2014, 6, 25}, 
                 73.504602909088}, {{2014, 6, 26}, 73.358702659607}, {{2014, 
                 6, 27}, 73.454600572586}, {{2014, 6, 28}, 
                 73.260098695755}, {{2014, 6, 29}, 73.260098695755}, {{2014, 
                 6, 30}, 73.282599449158}, {{2014, 7, 1}, 
                 73.03829789161699}, {{2014, 7, 2}, 73.099398612976}, {{2014, 
                 7, 3}, 73.223298788071}, {{2014, 7, 4}, 73.475098609924}, {{
                 2014, 7, 5}, 73.556500673294}, {{2014, 7, 6}, 
                 73.556500673294}, {{2014, 7, 7}, 73.59380125999499}, {{2014, 
                 7, 8}, 73.492699861526}, {{2014, 7, 9}, 73.460799455643}, {{
                 2014, 7, 10}, 73.313498497009}, {{2014, 7, 11}, 
                 73.48889708518999}, {{2014, 7, 12}, 73.489499092102}, {{2014,
                  7, 13}, 73.489499092102}, {{2014, 7, 14}, 
                 73.50509762764}, {{2014, 7, 15}, 73.418700695038}, {{2014, 7,
                  16}, 73.70169758796699}, {{2014, 7, 17}, 
                 73.926198482513}, {{2014, 7, 18}, 73.953598737717}, {{2014, 
                 7, 19}, 73.93400073051501}, {{2014, 7, 20}, 
                 73.93400073051501}, {{2014, 7, 21}, 73.90159964561501}, {{
                 2014, 7, 22}, 73.947298526764}, {{2014, 7, 23}, 
                 74.258100986481}, {{2014, 7, 24}, 74.299198389053}, {{2014, 
                 7, 25}, 74.276500940323}, {{2014, 7, 26}, 
                 74.45999979972801}, {{2014, 7, 27}, 74.45999979972801}, {{
                 2014, 7, 28}, 74.453800916672}, {{2014, 7, 29}, 
                 74.411702156067}, {{2014, 7, 30}, 74.576497077942}, {{2014, 
                 7, 31}, 74.656099081039}, {{2014, 8, 1}, 74.693500995636}, {{
                 2014, 8, 2}, 74.4520008564}, {{2014, 8, 3}, 
                 74.4520008564}, {{2014, 8, 4}, 74.48850274086}, {{2014, 8, 
                 5}, 74.505400657654}, {{2014, 8, 6}, 74.79540109634401}, {{
                 2014, 8, 7}, 74.721401929855}, {{2014, 8, 8}, 
                 74.848902225494}, {{2014, 8, 9}, 74.561500549316}, {{2014, 8,
                  10}, 74.561500549316}, {{2014, 8, 11}, 74.594300985336}, {{
                 2014, 8, 12}, 74.711102247238}, {{2014, 8, 13}, 
                 74.803501367569}, {{2014, 8, 14}, 74.821698665619}, {{2014, 
                 8, 15}, 74.828499555588}, {{2014, 8, 16}, 
                 74.637997150421}, {{2014, 8, 17}, 74.637997150421}, {{2014, 
                 8, 18}, 74.684798717499}, {{2014, 8, 19}, 
                 74.84920024871799}, {{2014, 8, 20}, 75.073897838593}, {{2014,
                  8, 21}, 75.414800643921}, {{2014, 8, 22}, 
                 75.29810070991499}, {{2014, 8, 23}, 75.51149725914}, {{2014, 
                 8, 24}, 75.51149725914}, {{2014, 8, 25}, 75.808399915695}, {{
                 2014, 8, 26}, 75.829100608826}, {{2014, 8, 27}, 
                 75.940501689911}, {{2014, 8, 28}, 75.79950094223}, {{2014, 8,
                  29}, 75.86100101470899}, {{2014, 8, 30}, 
                 76.139497756958}, {{2014, 8, 31}, 76.139497756958}, {{2014, 
                 9, 1}, 76.133900880814}, {{2014, 9, 2}, 
                 76.16320252418501}, {{2014, 9, 3}, 76.13540291786201}, {{
                 2014, 9, 4}, 76.03639960289}, {{2014, 9, 5}, 
                 77.302199602127}, {{2014, 9, 6}, 77.20819711685199}, {{2014, 
                 9, 7}, 77.20819711685199}, {{2014, 9, 8}, 
                 77.19150185584999}, {{2014, 9, 9}, 77.535897493362}, {{2014, 
                 9, 10}, 77.30929851532}, {{2014, 9, 11}, 77.382302284241}, {{
                 2014, 9, 12}, 77.384102344513}, {{2014, 9, 13}, 
                 77.1399974823}, {{2014, 9, 14}, 77.1399974823}, {{2014, 9, 
                 15}, 77.145600318909}, {{2014, 9, 16}, 77.28989720344501}, {{
                 2014, 9, 17}, 77.218902111053}, {{2014, 9, 18}, 
                 77.893102169037}, {{2014, 9, 19}, 77.415901422501}, {{2014, 
                 9, 20}, 77.948397397995}, {{2014, 9, 21}, 
                 77.948397397995}, {{2014, 9, 22}, 77.907001972198}, {{2014, 
                 9, 23}, 77.828001976013}, {{2014, 9, 24}, 
                 77.84219980239901}, {{2014, 9, 25}, 78.26550006866499}, {{
                 2014, 9, 26}, 78.387701511383}, {{2014, 9, 27}, 
                 78.84200215339699}, {{2014, 9, 28}, 78.84200215339699}, {{
                 2014, 9, 29}, 78.914499282837}, {{2014, 9, 30}, 
                 78.798800706863}, {{2014, 10, 1}, 79.17839884758}, {{2014, 
                 10, 2}, 79.220497608185}, {{2014, 10, 3}, 
                 78.924697637558}, {{2014, 10, 4}, 79.910498857498}, {{2014, 
                 10, 5}, 79.910498857498}, {{2014, 10, 6}, 
                 79.936397075653}, {{2014, 10, 7}, 79.029202461243}, {{2014, 
                 10, 8}, 78.92689704895}, {{2014, 10, 9}, 78.556400537491}, {{
                 2014, 10, 10}, 78.836101293564}, {{2014, 10, 11}, 
                 79.183000326157}, {{2014, 10, 12}, 79.183000326157}, {{2014, 
                 10, 13}, 79.07509803772001}, {{2014, 10, 14}, 
                 78.522801399231}, {{2014, 10, 15}, 79.082602262497}, {{2014, 
                 10, 16}, 77.97269821167}, {{2014, 10, 17}, 
                 78.07739973068199}, {{2014, 10, 18}, 78.37849855423}, {{2014,
                  10, 19}, 78.37849855423}, {{2014, 10, 20}, 
                 78.471398353577}, {{2014, 10, 21}, 78.162598609924}, {{2014, 
                 10, 22}, 78.670799732208}, {{2014, 10, 23}, 
                 79.068899154663}, {{2014, 10, 24}, 79.04509902000399}, {{
                 2014, 10, 25}, 78.92040014267}, {{2014, 10, 26}, 
                 78.92040014267}, {{2014, 10, 27}, 78.88860106468199}, {{2014,
                  10, 28}, 78.764700889587}, {{2014, 10, 29}, 
                 78.518497943878}, {{2014, 10, 30}, 79.128301143646}}, 1, 
               1]], $CellContext`lastdate$$ + 1.5 10^7}, Automatic}], 
         DateListPlot[{{{2012, 8, 17}, 78.60000193018918}, {{2012, 10, 10}, 
            80.30000234526402}, {{2013, 1, 13}, 82.85690608384199}, {{2013, 5,
             13}, 84.8320249437427}}, PlotStyle -> {
            Darker[Green], 
            PointSize[0.03]}, PlotLegends -> Column[{
             PointLegend[{
               Directive[
                Darker[Green], 
                AbsolutePointSize[8]]}, {"Past trades"}], 
             LineLegend[{Dashed}, {"Forecasts"}]}]], 
         If[$CellContext`alg1$$, 
          $CellContext`trendPlot[
          1, $CellContext`mtrend$$, $CellContext`risk$$], 
          Graphics[]], 
         If[$CellContext`alg2$$, 
          $CellContext`trendPlot[-1, $CellContext`mtrend$$, \
$CellContext`risk$$], 
          Graphics[]], 
         If[$CellContext`alg3$$, 
          $CellContext`trendPlot[
          0, $CellContext`mtrend$$, $CellContext`risk$$], 
          Graphics[]], 
         If[$CellContext`alg4$$, 
          $CellContext`trendPlot[
          1.5, $CellContext`mtrend$$, $CellContext`risk$$], 
          Graphics[]], 
         If[$CellContext`alg5$$, 
          $CellContext`trendPlot[
          2, $CellContext`mtrend$$, $CellContext`risk$$], 
          Graphics[]], 
         FrameLabel -> {{"\[Sterling]", None}, {
           "Date", "\[Euro] Exchange rate"}}, ImageSize -> 400, PlotRange -> 
         All, Epilog -> 
         Line[{{$CellContext`lastdate$$, 0}, {$CellContext`lastdate$$, 90}}]],
         StandardForm],
       ImageSizeCache->{523., {140., 145.}}]},
     {
      TemplateBox[{ButtonBox["\"Trade now\"", ButtonFunction :> CreateDialog[
           Grid[{{"You are now being sent to your currency trading service"}, {
              ProgressIndicator[
               Dynamic[
                Clock[Infinity]], Indeterminate]}}, Alignment -> Center, 
            ItemStyle -> "Text"]], Appearance -> Automatic, Evaluator -> 
         Automatic, Method -> "Preemptive"],ButtonBox[
        "\"Schedule new alert and close notebook\"", ButtonFunction :> 
         NotebookClose[
           ButtonNotebook[]], Appearance -> Automatic, Evaluator -> Automatic,
          Method -> "Preemptive"]},
       "RowDefault"], "\<\"\"\>"}
    },
    AutoDelete->False,
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{},
  Initialization:>($CellContext`estimateFn[
      Pattern[$CellContext`x$, 
       Blank[]], 
      Pattern[$CellContext`slope$, 
       Blank[]]] := ($CellContext`slope$ - 1) 
      1.*^-7 ($CellContext`x$ - $CellContext`lastdate$$) + \
$CellContext`lastval$$; $CellContext`trendPlot[
      Pattern[$CellContext`estTrend$, 
       Blank[]], 
      Pattern[$CellContext`mytrend$, 
       Blank[]], 
      Pattern[$CellContext`risk$, 
       Blank[]]] := Plot[{
       $CellContext`estimateFn[$CellContext`x, $CellContext`estTrend$ + \
$CellContext`mytrend$], 
       $CellContext`estimateFn[$CellContext`x, $CellContext`estTrend$ + \
($CellContext`risk$ - 1) + $CellContext`mytrend$], 
       $CellContext`estimateFn[$CellContext`x, $CellContext`estTrend$ + (
         1 - $CellContext`risk$) + $CellContext`mytrend$]}, {$CellContext`x, \
$CellContext`lastdate$$, $CellContext`lastdate$$ + 0.0005 10^9 + 1.5 10^7}, 
      PlotStyle -> Dashed]; Null)]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1000, 730},
WindowTitle->"Currency Trade Alert",
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
TaggingRules->{"NotebookTemplateVersion" -> 1.},
CellContext->Notebook,
ShowCellTags->True,
TrackCellChangeTimes->False,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1520, 36, 46, 0, 92, "Title"],
Cell[CellGroupData[{
Cell[1591, 40, 197, 4, 69, "Subsection"],
Cell[1791, 46, 38744, 595, 335, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature PK4ZCmEo9xuhEL#@aIqTX69U *)
