(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     18038,        429]
NotebookOptionsPosition[     17415,        404]
NotebookOutlinePosition[     17994,        425]
CellTagsIndexPosition[     17951,        422]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Set Up a Currency Trade Alert", "Title",
 CellChangeTimes->{{3.62281698822335*^9, 3.6228169933273497`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Analyze exchange rate trends with advanced forecasting algorithms, and make \
trading decisions based on trade deadline, estimated future trend, and risk \
preference.\
\>", "Subsection",
 CellChangeTimes->{{3.62281699682335*^9, 3.62281702336535*^9}, 
   3.6236714866969147`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tradeInterface", "[", "dateValues_", "]"}], ":=", 
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"alg1", "=", "False"}], ",", 
       RowBox[{"alg2", "=", "False"}], ",", 
       RowBox[{"alg3", "=", "True"}], ",", 
       RowBox[{"alg4", "=", "False"}], ",", 
       RowBox[{"alg5", "=", "False"}], ",", 
       RowBox[{"deadline", "=", "0.2"}], ",", 
       RowBox[{"mtrend", "=", "0.5"}], ",", 
       RowBox[{"risk", "=", "0.5"}], ",", 
       RowBox[{"lastdate", "=", 
        RowBox[{"AbsoluteTime", "[", 
         RowBox[{Cell[BoxData[
           FormBox[
            
            TemplateBox[{
             "\"currencyHistoryData\"","\"currencyHistoryData\"","Named",
              BoxData},
             "NotebookTemplateSlot"], TextForm]]], "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"lastval", "=", 
        RowBox[{Cell[BoxData[
          FormBox[
           
           TemplateBox[{
            "\"currencyHistoryData\"","\"currencyHistoryData\"","Named",
             BoxData},
            "NotebookTemplateSlot"], TextForm]]], "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Grid", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Panel", "[", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Your Parameters\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft", ",", "SpanFromLeft"}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Estimated next trade deadline\>\"", ",", 
                 RowBox[{"Slider", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", "deadline", "]"}], ",", 
                   RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
                 "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Estimated future trend\>\"", ",", 
                 RowBox[{"Slider", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", "mtrend", "]"}], ",", 
                   RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
                 "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Risk preference\>\"", ",", 
                 RowBox[{"Slider", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", "risk", "]"}], ",", 
                   RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
                 "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<\>\"", ",", "\"\<\>\""}], "}"}], ",", 
               "\[IndentingNewLine]", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Forecast Algorithm\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft", ",", "SpanFromLeft"}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Inertia\>\"", ",", 
                 RowBox[{"Checkbox", "[", 
                  RowBox[{"Dynamic", "[", "alg1", "]"}], "]"}], ",", 
                 RowBox[{"Dynamic", "@", 
                  RowBox[{"If", "[", 
                   RowBox[{"alg1", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"risk", "-", "mtrend", "+", "deadline"}], "<", 
                    "0.4"}], ",", "\"\<Trade\>\"", ",", "\"\<Wait\>\""}], 
                    "]"}], ",", "\"\<\>\""}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Futures market\>\"", ",", 
                 RowBox[{"Checkbox", "[", 
                  RowBox[{"Dynamic", "[", "alg2", "]"}], "]"}], ",", 
                 RowBox[{"Dynamic", "@", 
                  RowBox[{"If", "[", 
                   RowBox[{"alg2", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"risk", "-", "mtrend", "+", "deadline"}], "<", 
                    "0"}], ",", "\"\<Trade\>\"", ",", "\"\<Wait\>\""}], "]"}],
                     ",", "\"\<\>\""}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Klinger Oscillator\>\"", ",", 
                 RowBox[{"Checkbox", "[", 
                  RowBox[{"Dynamic", "[", "alg3", "]"}], "]"}], ",", 
                 RowBox[{"Dynamic", "@", 
                  RowBox[{"If", "[", 
                   RowBox[{"alg3", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"risk", "-", "mtrend", "+", "deadline"}], "<", 
                    "0.2"}], ",", "\"\<Trade\>\"", ",", "\"\<Wait\>\"", ",", 
                    "\"\<\>\""}], "]"}]}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Random walk index\>\"", ",", 
                 RowBox[{"Checkbox", "[", 
                  RowBox[{"Dynamic", "[", "alg4", "]"}], "]"}], ",", 
                 RowBox[{"Dynamic", "@", 
                  RowBox[{"If", "[", 
                   RowBox[{"alg4", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"risk", "-", "mtrend", "+", "deadline"}], "<", 
                    "0.8"}], ",", "\"\<Trade\>\"", ",", "\"\<Wait\>\""}], 
                    "]"}], ",", "\"\<\>\""}], "]"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"\"\<Linear regression trendlines\>\"", ",", 
                 RowBox[{"Checkbox", "[", 
                  RowBox[{"Dynamic", "[", "alg5", "]"}], "]"}], ",", 
                 RowBox[{"Dynamic", "@", 
                  RowBox[{"If", "[", 
                   RowBox[{"alg5", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"risk", "-", "mtrend", "+", "deadline"}], "<", 
                    "2"}], ",", "\"\<Trade\>\"", ",", "\"\<Wait\>\""}], "]"}],
                     ",", "\"\<\>\""}], "]"}]}]}], "}"}]}], 
              "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
             RowBox[{"Dividers", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                 "False", ",", "False", ",", "False", ",", "False", ",", 
                  "False", ",", "False", ",", "True", ",", 
                  RowBox[{"{", "False", "}"}]}], "}"}]}], "}"}]}]}], "]"}], 
           "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Dynamic", "@", 
           RowBox[{"Show", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"DateListPlot", "[", 
              RowBox[{Cell[BoxData[
                FormBox[
                 
                 TemplateBox[{
                  "\"currencyHistoryData\"","\"currencyHistoryData\"","Named",
                   BoxData},
                  "NotebookTemplateSlot"], TextForm]]], ",", 
               RowBox[{"Joined", "\[Rule]", "True"}], ",", 
               RowBox[{"PlotRange", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"AbsoluteTime", "[", 
                    RowBox[{Cell[BoxData[
                    FormBox[
                    
                    TemplateBox[{
                    "\"currencyHistoryData\"","\"currencyHistoryData\"",
                    "Named",BoxData},
                    "NotebookTemplateSlot"], TextForm]]], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"lastdate", "+", 
                    RowBox[{"1.5", "*", 
                    RowBox[{"10", "^", "7"}]}]}]}], "}"}], ",", "Automatic"}],
                  "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"DateListPlot", "[", 
              RowBox[{"dateValues", ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Darker", "@", "Green"}], ",", 
                  RowBox[{"PointSize", "[", "0.03", "]"}]}], "}"}]}], ",", 
               RowBox[{"PlotLegends", "\[Rule]", 
                RowBox[{"Column", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"PointLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Darker", "@", "Green"}], ",", 
                    RowBox[{"AbsolutePointSize", "[", "8", "]"}]}], "]"}], 
                    "}"}], ",", 
                    RowBox[{"{", "\"\<Past trades\>\"", "}"}]}], "]"}], ",", 
                   RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", "Dashed", "}"}], ",", 
                    RowBox[{"{", "\"\<Forecasts\>\"", "}"}]}], "]"}]}], "}"}],
                  "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"alg1", ",", 
               RowBox[{"trendPlot", "[", 
                RowBox[{"1", ",", "mtrend", ",", "risk"}], "]"}], ",", 
               RowBox[{"Graphics", "[", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"alg2", ",", 
               RowBox[{"trendPlot", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "mtrend", ",", "risk"}], "]"}], ",", 
               RowBox[{"Graphics", "[", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"alg3", ",", 
               RowBox[{"trendPlot", "[", 
                RowBox[{"0", ",", "mtrend", ",", "risk"}], "]"}], ",", 
               RowBox[{"Graphics", "[", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"alg4", ",", 
               RowBox[{"trendPlot", "[", 
                RowBox[{"1.5", ",", "mtrend", ",", "risk"}], "]"}], ",", 
               RowBox[{"Graphics", "[", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{"alg5", ",", 
               RowBox[{"trendPlot", "[", 
                RowBox[{"2", ",", "mtrend", ",", "risk"}], "]"}], ",", 
               RowBox[{"Graphics", "[", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"\"\<\[Sterling]\>\"", ",", "None"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Date\>\"", ",", "\"\<\[Euro] Exchange rate\>\""}], 
                 "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
             RowBox[{"Epilog", "\[Rule]", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"lastdate", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"lastdate", ",", "90"}], "}"}]}], "}"}], "]"}]}]}], 
            "]"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Button", "[", 
              RowBox[{"\"\<Trade now\>\"", ",", 
               RowBox[{"CreateDialog", "[", 
                RowBox[{"Grid", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    "{", "\"\<You are now being sent to your currency trading \
service\>\"", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ProgressIndicator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"Clock", "[", "Infinity", "]"}], "]"}], ",", 
                    "Indeterminate"}], "]"}], "}"}]}], "}"}], ",", 
                  RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
                  RowBox[{"ItemStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}], 
                "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Button", "[", 
              RowBox[{"\"\<Schedule new alert and close notebook\>\"", ",", 
               RowBox[{"NotebookClose", "[", 
                RowBox[{"ButtonNotebook", "[", "]"}], "]"}]}], "]"}]}], "}"}],
            "]"}], ",", "\"\<\>\""}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Initialization", "\[RuleDelayed]", 
      RowBox[{"(", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"estimateFn", "[", 
          RowBox[{"x_", ",", "slope_"}], "]"}], ":=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"slope", "-", "1"}], ")"}], "*", "0.0000001", 
           RowBox[{"(", 
            RowBox[{"x", "-", "lastdate"}], ")"}]}], "+", "lastval"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"trendPlot", "[", 
          RowBox[{"estTrend_", ",", "mytrend_", ",", "risk_"}], "]"}], ":=", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"estimateFn", "[", 
              RowBox[{"x", ",", 
               RowBox[{"estTrend", "+", "mytrend"}]}], "]"}], ",", 
             RowBox[{"estimateFn", "[", 
              RowBox[{"x", ",", 
               RowBox[{"estTrend", "+", 
                RowBox[{"(", 
                 RowBox[{"risk", "-", "1"}], ")"}], "+", "mytrend"}]}], "]"}],
              ",", 
             RowBox[{"estimateFn", "[", 
              RowBox[{"x", ",", 
               RowBox[{"estTrend", "+", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "risk"}], ")"}], "+", "mytrend"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "lastdate", ",", 
             RowBox[{"lastdate", "+", 
              RowBox[{"0.0005", "*", 
               RowBox[{"10", "^", "9"}]}], "+", 
              RowBox[{"1.5", "*", 
               RowBox[{"10", "^", "7"}]}]}]}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}]}], ";"}], 
       ")"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"tradeInterface", "[", Cell[BoxData[
   FormBox[
    TemplateBox[{"\"dates\"","\"dates\"","Named",BoxData},
     "NotebookTemplateSlot"], TextForm]]], "]"}]}], "Input",
 CellFrameLabels->{{
    Cell[
     BoxData[
      TemplateBox[{"EvaluateDeleteInput"}, "NotebookTemplateCellBehavior"]]], 
    None}, {None, None}},
 CellChangeTimes->{{3.62282227925835*^9, 3.62282230768635*^9}, {
   3.62282239435835*^9, 3.62282240270935*^9}, 3.62282247935035*^9, {
   3.62282251343935*^9, 3.6228225318723497`*^9}, {3.62282257215935*^9, 
   3.6228225780953503`*^9}, {3.62282263289235*^9, 3.6228226433243504`*^9}, 
   3.6228227083723497`*^9, 3.6228227829043503`*^9, {3.62282296724535*^9, 
   3.62282301095035*^9}, {3.6236715281615477`*^9, 3.623671537848366*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1137, 842},
WindowMargins->{{Automatic, 225}, {25, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "NotebookTemplatingExpressions", "AuthoringDockedCell"],
TaggingRules->{"NotebookTemplateVersion" -> 1., "NotebookTemplate" -> True},
CellContext->Notebook,
ShowCellTags->True,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 113, 1, 92, "Title"],
Cell[CellGroupData[{
Cell[718, 27, 289, 6, 69, "Subsection"],
Cell[1010, 35, 16377, 365, 970, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
